==> facebook-common-5.15.1-sources.jar: com/facebook/share/internal/LikeButton.java <==
/**
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.facebook.share.internal;

import android.content.Context;
import android.support.v7.content.res.AppCompatResources;
import android.util.AttributeSet;
import com.facebook.FacebookButtonBase;
import com.facebook.common.R;
import com.facebook.internal.AnalyticsEvents;

/**
 * com.facebook.share.internal is solely for the use of other packages within the Facebook SDK for
 * Android. Use of any of the classes in this package is unsupported, and they may be modified or
 * removed without warning at any time.
 */
/**
 * @deprecated
 * LikeView is deprecated
 */
@Deprecated
public class LikeButton extends FacebookButtonBase {
    /**
     * @deprecated
     * LikeView is deprecated
     */
    @Deprecated
    public LikeButton(Context context, boolean isLiked) {
        super(context, null, 0, 0, AnalyticsEvents.EVENT_LIKE_BUTTON_CREATE,
                                   AnalyticsEvents.EVENT_LIKE_BUTTON_DID_TAP);
        this.setSelected(isLiked);
    }

    /**
     * @deprecated
     * LikeView is deprecated
     */
    @Deprecated
    @Override
    public void setSelected(boolean selected) {
        super.setSelected(selected);
        updateForLikeStatus();
    }

    @Override
    protected void configureButton(
            Context context,
            AttributeSet attrs,
            int defStyleAttr,
            int defStyleRes) {
        super.configureButton(context, attrs, defStyleAttr, defStyleRes);
        updateForLikeStatus();
    }

    @Override
    protected int getDefaultRequestCode() {
        return 0;
    }

    @Override
    protected int getDefaultStyleResource() {
        return R.style.com_facebook_button_like;
    }

    private void updateForLikeStatus() {
        // the compound drawables don't support selectors, so we need to update for the status
        if (isSelected()) {
            this.setCompoundDrawablesWithIntrinsicBounds(
                    R.drawable.com_facebook_button_like_icon_selected, 0, 0, 0);
            this.setText(getResources().getString(R.string.com_facebook_like_button_liked));
        } else {
            this.setCompoundDrawablesWithIntrinsicBounds(
                    AppCompatResources.getDrawable(
                            getContext(), R.drawable.com_facebook_button_icon),
                    null,
                    null,
                    null);
            this.setText(getResources().getString(R.string.com_facebook_like_button_not_liked));
        }
    }
}

==> facebook-common-7.0.0-sources.jar: com/facebook/share/internal/LikeButton.java <==
/**
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.facebook.share.internal;

import android.content.Context;
import android.util.AttributeSet;
import androidx.appcompat.content.res.AppCompatResources;
import com.facebook.FacebookButtonBase;
import com.facebook.common.R;
import com.facebook.internal.AnalyticsEvents;

/**
 * com.facebook.share.internal is solely for the use of other packages within the Facebook SDK for
 * Android. Use of any of the classes in this package is unsupported, and they may be modified or
 * removed without warning at any time.
 */
/**
 * @deprecated
 * LikeView is deprecated
 */
@Deprecated
public class LikeButton extends FacebookButtonBase {
    /**
     * @deprecated
     * LikeView is deprecated
     */
    @Deprecated
    public LikeButton(Context context, boolean isLiked) {
        super(context, null, 0, 0, AnalyticsEvents.EVENT_LIKE_BUTTON_CREATE,
                                   AnalyticsEvents.EVENT_LIKE_BUTTON_DID_TAP);
        this.setSelected(isLiked);
    }

    /**
     * @deprecated
     * LikeView is deprecated
     */
    @Deprecated
    @Override
    public void setSelected(boolean selected) {
        super.setSelected(selected);
        updateForLikeStatus();
    }

    @Override
    protected void configureButton(
            Context context,
            AttributeSet attrs,
            int defStyleAttr,
            int defStyleRes) {
        super.configureButton(context, attrs, defStyleAttr, defStyleRes);
        updateForLikeStatus();
    }

    @Override
    protected int getDefaultRequestCode() {
        return 0;
    }

    @Override
    protected int getDefaultStyleResource() {
        return R.style.com_facebook_button_like;
    }

    private void updateForLikeStatus() {
        // the compound drawables don't support selectors, so we need to update for the status
        if (isSelected()) {
            this.setCompoundDrawablesWithIntrinsicBounds(
                    R.drawable.com_facebook_button_like_icon_selected, 0, 0, 0);
            this.setText(getResources().getString(R.string.com_facebook_like_button_liked));
        } else {
            this.setCompoundDrawablesWithIntrinsicBounds(
                    AppCompatResources.getDrawable(
                            getContext(), R.drawable.com_facebook_button_icon),
                    null,
                    null,
                    null);
            this.setText(getResources().getString(R.string.com_facebook_like_button_not_liked));
        }
    }
}
